
function initCanvas() {
    var canvas = document.getElementById('printcanvas');
    var ctx = canvas.getContext('2d');

    // last known position
    var pos = { x: 0, y: 0 };

    canvas.addEventListener('mousemove', draw);
    canvas.addEventListener('mousedown', setPosition);
    canvas.addEventListener('mouseenter', setPosition);

    canvas.addEventListener('touchmove', draw);
    canvas.addEventListener('touchstart', setPosition);
    canvas.addEventListener('touchend', setPosition);

    // new position from mouse event
    function setPosition(e) {
        if (e instanceof MouseEvent) {
            setPositionOffset(e.offsetX, e.offsetY);
        } else {
            // Touch event, basic management
            if (e.touches.length > 0) {
                var last = e.touches.length - 1;
                setPositionOffset(
                    e.touches[last].pageX - e.target.offsetLeft, 
                    e.touches[last].pageY - e.target.offsetTop);
            }
            e.preventDefault();
        }
    }

    function setPositionOffset(offsetX, offsetY) {
        pos.y = canvas.height * offsetY / canvas.clientHeight;
        pos.x = canvas.width * offsetX / canvas.clientWidth;
    }

    function draw(e) {
        // mouse left button must be pressed
        if ((   e instanceof MouseEvent) && (e.buttons !== 1)) return;

        ctx.beginPath(); // begin

        ctx.lineWidth = 5;
        ctx.lineCap = 'round';
        ctx.strokeStyle = '#000000';

        ctx.moveTo(pos.x, pos.y); // from
        //console.log("moveTo " +  pos.x + ", " + pos.y);
        setPosition(e);
        ctx.lineTo(pos.x, pos.y); // to
        //console.log("lineTo " +  pos.x + ", " + pos.y);

        ctx.stroke(); // draw it!
    }



}

function loadCanvas(url) {
    return new Promise(function(resolve, reject) {
        var canvas = document.getElementById('printcanvas');
        var ctx = canvas.getContext('2d');
        var img = new Image();
        img.onload = function() {        
            ctx.clearRect(0, 0, canvas.width, canvas.height);
    
            var position = getImagePosition(canvas, img);
            ctx.drawImage(img, position.x, position.y, position.w, position.h);
            resolve();
        }
        img.onerror = function() {
            reject();
        }
        img.src = url;
    });

}

function getImagePosition(canvas, image) {
    if (canvas.width / canvas.height >= image.width / image.height) {
        // Fit on canvas height
        var w = image.width * canvas.height / image.height;        
        return {
            x: (canvas.width - w) / 2,
            y: 0,
            w: w,
            h: canvas.height
        }
    } else {
        // Fit on canvas width
        var h = image.height * canvas.width / image.width;
        return {
            x: 0,
            y: (canvas.height - h) / 2,
            w: canvas.width,
            h: h
        }
    }

        
}